#
# spec file for package tpm2-tss-engine
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _bashcompletionsdir %{_datadir}/bash-completion/completions
# The directory where crypto engines are located is owned by the libcrypto package.
# Find out where that is.
%define _ENGINE_DIR %(pkg-config --variable=enginesdir libcrypto)
Name:           tpm2-tss-engine
Version:        1.0.1
Release:        4.3.1
Summary:        OpenSSL Engine for TPM2 devices
License:        BSD-3-Clause
Group:          Productivity/Security
URL:            https://github.com/tpm2-software
Source0:        %{url}/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Patch0:         0001-build-add-disable-defaultflags.patch
BuildRequires:  autoconf-archive
BuildRequires:  libgcrypt-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  tpm2-0-tss-devel
BuildRequires:  pkgconfig(libcrypto)

%description
The tpm2-tss-engine project implements a cryptographic engine for OpenSSL for
Trusted Platform Module (TPM 2.0) using the tpm2-tss software stack that follows
the Trusted Computing Groups (TCG) TPM Software Stack (TSS 2.0). It uses the
Enhanced System API (ESAPI) interface of the TSS 2.0 for downwards communication.
It supports RSA decryption and signatures as well as ECDSA signatures.

%package bash-completion
Summary:        Bash completion for tpm2-tss-engine
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    packageand(bash-completion:%{name})
BuildArch:      noarch

%description bash-completion
Optional dependency offering bash completion for the tpm2-tss-engine project.

%package devel
Summary:        Devel files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Development files for tpm2-tss-engine, an OpenSSL engine for TPM2 devices.

The tpm2-tss-engine project implements a cryptographic engine for OpenSSL for
Trusted Platform Module (TPM 2.0) using the tpm2-tss software stack that follows
the Trusted Computing Groups (TCG) TPM Software Stack (TSS 2.0). It uses the
Enhanced System API (ESAPI) interface of the TSS 2.0 for downwards communication.
It supports RSA decryption and signatures as well as ECDSA signatures.

%prep
%autosetup

%build

autoreconf -fvi
%configure --with-enginesdir=%{_ENGINE_DIR} --disable-static --disable-defaultflags
make %{?_smp_mflags}

%install
%make_install bash_completiondir=%{_bashcompletionsdir}
rm %{buildroot}/%{_ENGINE_DIR}/libtpm2tss.la

%files
%doc CHANGELOG.md CONTRIBUTING.md INSTALL.md README.md
%license LICENSE
%{_bindir}/tpm2tss-genkey
%{_mandir}/man1/tpm2tss-genkey.1%{?ext_man}
%{_mandir}/man3/tpm2tss_ecc_genkey.3%{?ext_man}
%{_mandir}/man3/tpm2tss_ecc_getappdata.3%{?ext_man}
%{_mandir}/man3/tpm2tss_ecc_makekey.3%{?ext_man}
%{_mandir}/man3/tpm2tss_ecc_setappdata.3%{?ext_man}
%{_mandir}/man3/tpm2tss_rsa_genkey.3%{?ext_man}
%{_mandir}/man3/tpm2tss_rsa_makekey.3%{?ext_man}
%{_mandir}/man3/tpm2tss_tpm2data_read.3%{?ext_man}
%{_mandir}/man3/tpm2tss_tpm2data_write.3%{?ext_man}
%{_ENGINE_DIR}/libtpm2tss.so
%{_ENGINE_DIR}/tpm2tss.so

%files bash-completion
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_bashcompletionsdir}/tpm2tss-genkey

%files devel
%{_includedir}/tpm2-tss-engine.h

%changelog
* Wed Mar  3 2021 matthias.gerstner@suse.com
- add 0001-build-add-disable-defaultflags.patch: add support to disable fixed
  compilation flags
- pass --disable-defaultflags to avoid breakage of our gcc-PIE profile
  (resulted in non-position-independent executable tpm2-tss-genkey, bsc#1183895).
* Thu Apr 23 2020 matthias.gerstner@suse.com
- remove conditional pandoc BuildRequires for openSUSE. Nothing much is gained
  from rebuilding the man pages. This shall help synchronizing SLE and
  openSUSE package builds. (jsc#SLE-12137).
* Fri Jan 10 2020 matthias.gerstner@suse.com
- remove the _service file as requested in declined OBS sr#762653.
  download_files seems to work also without the _service file.
* Fri Jan 10 2020 matthias.gerstner@suse.com
- switch the _service approach from using tar_scm to using download_files. We
  need to use the actual release tarball which contains the generated man
  pages. The reason is that on SLE we can't generate the man pages using
  pandoc, since pandoc is not available on SLE.
- for the same reason make the pandoc BuildRequires conditional for openSUSE
  vs. SLE.
* Tue Jan  7 2020 matthias.gerstner@suse.com
- Update to stable upstream version v1.0.1:
  * Release v1.0.1
  * test: use tpm2-tools 3.X
  * Tests: Fix for latest tools
  * Tests: Use long parameters for tpm2-tools
  * test: migrate tpm2_create option from -A to -b
  * build: link against tss2-mu
  * Release v1.0.0
  * Release v1.0.0-rc3
  * Docu: Update Install.md
  * Updates for 1.0.0-rc2
  * TESTS: Add test for client auth
  * Bump required version of tpm2-tss to >=2.2.2
  * Build: Bump required tpm2-tss to 2.2
  * Update for v1.0.0-rc1
  * Dead code removal
- This fixes the build against tpm2-0-tss version >= 2.3 (bsc#1160123)
* Fri Dec 20 2019 matthias.gerstner@suse.com
- move *.so files into the main package, not -devel. libtpm2tss.so is actually
  the engine library itself, not a symlink. It's needed to actually use the
  package. tpm2tss.so is probably a (backwards) compatiblity symlink. Both are
  not intended for linking and therefore not suitable for the -devel package.
* Sun Mar  3 2019 jsikes@suse.de
- Update to version 0+git20190222.cef2c43:
  * build: install existing man pages even if pandoc is not available
  * Updated organizational files in preparation for release
  * Add configure switch for unit and integration tests
  * Silence clang warning on field initializers
  * Fix parallel connections to TPM.
  * Fix segfault on non-null auth'd persistent keys.
  * Update tests to also run on physical TPMs
  * build: install aclocal files
  * build: update for ax_code_coverage.m4 version 2019.01.06
  * ECDSA truncation and s_server test
* Thu Jan 31 2019 jsikes@suse.de
- Now tpm2-tss-engine-bash-completion auto-installs only when bash-completion
  is present.
- Changed author of comment dated "Wed Jan 23 04:39:01 UTC 2019" from
  opensuse-packaging@opensuse.org to me.
* Wed Jan 23 2019 jengelh@inai.de
- Build bash-completion as noarch.
* Wed Jan 23 2019 jsikes@suse.de
- Update to version 0+git20190115.6cfaeb7:
  * Initialize/Finalize TCTI based on opts
  * init_tpm_parent: use ESYS_AUXCONTEXT as 1st argument
  * init_tpm_key: use ESYS_AUXCONTEXT as 1st argument
  * tpm2-tss-engine-ecc.c: use ESYS_AUXCONTEXT
  * tpm2-tss-engine-rsa.c: use ESYS_AUXCONTEXT
  * tpm2-tss-engine-rand.c: use ESYS_AUXCONTEXT
  * tpm2tss_tpm2data_readtpm: use ESYS_AUXCONTEXT
  * tpm2-tss-engine-common.(c/h): Add ESYS_AUXCONTEXT
  * Set TCTI option through an environment variable
  * Add new engine control to set the TCTI option
* Mon Dec 24 2018 jsikes@suse.de
- Initial import
  * version 0.0+git20181128.c9061a7
  * FATE 325619
